function [phi_odd phi_even]=coph(x1,x2)

% The congruent phase estimation between two signals
% with multiple frequencies and long length data > N*3+1
% x1 is the main (principle, foundamental) component
% phi_odd is the odd harmonic congruent phase angle in Degrees
% phi_even is the even harmonic congruent phase angle in Degrees
%
% Example:  [phi_odd phi_even]=coph(x1,x2);
%
%  2011 Michael Feldman
% For use with the book "HILBERT TRANSFORM APPLICATION
% IN MECHANICAL VIBRATION", John Wiley & Sons, 2011


if length(x1)~=length(x2),disp('wrong length data'),return,end
if length(x1)<=230*3,disp('too short data'),return,end
[A1,F1,phi1]=inst(x1,1);
[A2,F2,phi2]=inst(x2,1);
f1=lpf(F1,0.02);
f2=lpf(F2,0.02);

f1(f1==0)=eps; % avoid division by zero
r=round(f2./f1);
rd=diff(r);
ind=find(abs(rd)>=1)+1;
if isempty(ind)==1,seg_number=1; index=1:length(r); ii=1;
m=round(mean(r(index))); x1i=cos(m*phi1(index));x2i=cos(phi2(index));
if mod(m,2)==1, ph_p=phaseh(x1i,x2i); ph_n=ph_p;else ph_p=phaseh(x1i,x2i); ph_n=ph_p+180;end
else
    seg_number=length(ind)+1;
    for ii=1:seg_number
        if ii==1, index=1:ind(ii)-1;
            if length(index)<=230*3,ph_p{ii}=90.*ones(length(index),1);ph_n{ii}=ph_p{ii};
            else
                m=round(mean(r(index)));x1i=cos(m*phi1(index));x2i=cos(phi2(index));
                ph_p{ii}=phaseh(x1i,x2i); if mod(m,2)==1, ph_n{ii}=ph_p{ii}; else ph_n{ii}=ph_p{ii}+180;end
            end

        elseif ii==seg_number,index=ind(ii-1):length(r);
            if length(index)<=230*3,ph_p{ii}=90.*ones(length(index),1);ph_n{ii}=ph_p{ii};
            else
        m=round(mean(r(index)));x1i=cos(m*phi1(index));x2i=cos(phi2(index));
        ph_p{ii}=phaseh(x1i,x2i); if mod(m,2)==1, ph_n{ii}=ph_p{ii}; else ph_n{ii}=ph_p{ii}+180;end
            end

        else index=ind(ii-1):ind(ii)-1;
            if length(index)<=230*3,ph_p{ii}=90.*ones(length(index),1);ph_n{ii}=ph_p{ii};
            else
        m=round(mean(r(index))); x1i=cos(m*phi1(index));x2i=cos(phi2(index));
        ph_p{ii}=phaseh(x1i,x2i);if mod(m,2)==1, ph_n{ii}=ph_p{ii}; else ph_n{ii}=ph_p{ii}+180;end
            end

        end
    end
end
phi_odd=[];phi_even=[];
for jj=1:ii
    phi_odd =[phi_odd; ph_p{:,jj}];  % positive congruent phase shift
    phi_even=[phi_even; ph_n{:,jj}]; % negative congruent phase shift
end
